@@ -3,7 +3,7 @@ from typing import Final, Dict
 GQL_TO_PY_SIMPLE_TYPE_MAP: Final[Dict[str, str]] = {
     "String": "str",
     "ID": "str",
-    "Integer": "int",
+    "Int": "int",
     "Boolean": "bool",
     "Float": "float",
 }
